Coverage for /root/GitHubProjects/impacket/impacket/examples/ntlmrelayx/attacks/dcsyncattack.py: 86%

# Coverage for /root/GitHubProjects/impacket/impacket/examples/ntlmrelayx/attacks/dcsyncattack.py : 86%

## 7 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1# SECUREAUTH LABS. Copyright 2018 SecureAuth Corporation. All rights reserved.

2#

3# This software is provided under under a slightly modified version

4# of the Apache Software License. See the accompanying LICENSE file

5# for more information.

6#

7# HTTP Attack Class

8#

9# Authors:

10# Alberto Solino (@agsolino)

11# Dirk-jan Mollema (@_dirkjan) / Fox-IT (https://www.fox-it.com)

12#

13# Description:

14# HTTP protocol relay attack

15#

16# ToDo:

17#

18 from impacket.examples.ntlmrelayx.attacks import ProtocolAttack

19 from impacket.examples.secretsdump import RemoteOperations, SAMHashes, NTDSHashes

20

21 PROTOCOL_ATTACK_CLASS = "DCSYNCAttack"

22

23 class DCSYNCAttack(ProtocolAttack):

24 """

25 This is the default HTTP attack. This attack only dumps the root page, though

26 you can add any complex attack below. self.client is an instance of urrlib.session

27 For easy advanced attacks, use the SOCKS option and use curl or a browser to simply

28 proxy through ntlmrelayx

29 """

30 PLUGIN_NAMES = ["DCSYNC"]

31 def run(self):

32 return